@@ -16,7 +16,7 @@ static int		verbose;
 static int		timeout_seconds = 60;
 
 /* If libc provides no timeout variant: try to do without it: */
-#ifndef HAVE_SEMTIMEDEOP
+#ifndef HAVE_SEMTIMEDOP
 #define  semtimedop(sem, ops, n, timeout)    semop(sem, ops, n)
 #endif
 
